#
#  Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
#  This file is licensed under the Apache License, Version 2.0 (the "License").
#  You may not use this file except in compliance with the License. A copy of
#  the License is located at
# 
#  http://aws.amazon.com/apache2.0/
# 
#  This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
#  CONDITIONS OF ANY KIND, either express or implied. See the License for the
#  specific language governing permissions and limitations under the License.
#
import random
import json
import re
import cognito_utils
import ddb_utils
import uuid
from getpass import getpass

# Read parameters for the stack
with open("stackInputs.json", encoding='utf-8-sig') as json_file_text:
    stack_params = json.load(json_file_text)

# Read the stack output parameters
with open("stackOutputs.json", encoding='utf-8-sig') as json_file_text:
    list_of_outputs = json.load(json_file_text)

# Prompt the user and get the username and password
userName = input("Please enter the username: ")
email = input("Please enter the email: ")
if not re.match(r"^[A-Za-z0-9\.\+_-]+@[A-Za-z0-9\._-]+\.[a-zA-Z]*$", email):
    print("Email format is invalid.")
    exit()

print("Please enter password for the user...")
print("Password must be at least 8 characters but fewer than 99 characters.")
print("Password must have a number.")
print("Password requires a special character from this set: ^ $ * . [ ] { } ( ) ? - \" ! @ # % & / \ , > < ' : ; | _ ~ `")
print("Password requires an uppercase letter")
print("Password requires a lowercase letter")
password = getpass()
if not re.match(r"^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[\^$*.\[\]{}\(\)?\-“!@#%&/,><\’:;|_~`])\S{8,99}$", password):
    print("Invalid Password. Exiting....")
    exit()

#Setup a data structure with information about users to create
usersInfo = [
    {
        "CognitoUserPoolClientId": list_of_outputs["CognitoUserPoolClientId"],
        "CongnitoUserPoolId": list_of_outputs["CongnitoUserPoolId"],
        "usrname": userName,
        "email": email,
        "pwd": password
    }
]

#Call the function that populates the DynamoDB table with some information for the user. 
ddbInputParameters = {
    "tableName": stack_params["tableName"],
    "ddbRecords": [
        {
            'userName': {"S": userName},
            'projects': {"S": "[{\"projectId\": \"Project_" + str(uuid.uuid4()) + "\"}]"}
        }
    ]
}

try:
    ddb_utils.loadPreTokenDDB(ddbInputParameters)
    print("The DynamoDb data is loaded.")
except Exception as e:
    print(e)
    raise e

#Call the function that adds users to Cognito
try:
    for userInfo in usersInfo:
        cognito_utils.createPreTokenUsers(userInfo)
        print("The user ", userInfo["usrname"], " is created!")
except Exception as e:
    print(e)
    raise e

