#
#  Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
#  This file is licensed under the Apache License, Version 2.0 (the "License").
#  You may not use this file except in compliance with the License. A copy of
#  the License is located at
# 
#  http://aws.amazon.com/apache2.0/
# 
#  This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
#  CONDITIONS OF ANY KIND, either express or implied. See the License for the
#  specific language governing permissions and limitations under the License.
#
import boto3
from botocore.exceptions import ClientError

def getLambdaArn(lambdaFunctionName):
    client = boto3.client('lambda')
    response = client.get_function(
        FunctionName=lambdaFunctionName,
    )
    return response["Configuration"]["FunctionArn"]

def configureLambdaResourceBasedPolicy(configureLambdaResourceBasedPolicy_input):
    client = boto3.client('lambda')

    try:
        response = client.add_permission(
            Action='lambda:InvokeFunction',
            FunctionName=configureLambdaResourceBasedPolicy_input["LambdaFunction"],
            Principal='cognito-idp.amazonaws.com',
            SourceArn=configureLambdaResourceBasedPolicy_input["CongnitoUserPoolARN"],
            StatementId='RBP_PreTokenGeneration_'+ configureLambdaResourceBasedPolicy_input["CongnitoUserPoolId"],
        )

    except ClientError as e:
        print("Error configuring pre token generation trigger Resource Based Policy")
        raise e

    return
