// Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.

// This file is licensed under the Apache License, Version 2.0 (the "License").
// You may not use this file except in compliance with the License. A copy of
// the License is located at

// http://aws.amazon.com/apache2.0/

// This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
// CONDITIONS OF ANY KIND, either express or implied. See the License for the
// specific language governing permissions and limitations under the License.

import 'bootstrap/dist/css/bootstrap.min.css';
import React from 'react';
import Container from 'react-bootstrap/Container';
import Button from 'react-bootstrap/Button';
import './App.css';
import { redirectUrls } from './constants';

var jwtDecode = require('jwt-decode');
// var JSON = require('json');

function App() {

  function render_login() {
    window.location.href = redirectUrls.cognitoLoginURL;
  }

  function render_tokens() {
    const tokens = getToken();
    // Display tokens
    if (tokens) {
      document.getElementById('raw_id_token').value = tokens.id_token;
      const decoded = jwtDecode(tokens.id_token);

      document.getElementById('decoded_id_token').value = JSON.stringify(decoded, undefined, 2);

      if (decoded.projects) {
        var decoded_projects = JSON.parse(decoded.projects);
        var myProjects = '';
        for (var i = 0; i < decoded_projects.length; i++) {
          var obj = decoded_projects[i];
          myProjects += obj['projectId'] + '\n';
          console.log(myProjects);
        }
        document.getElementById('list_of_projects').value = myProjects;
      }

    }
  }

  // Returns the token from the URL hash
  function getToken() {
    const hash = parseParms(document.URL);
    return hash;
  }

  // Parses the URL parameters and returns an object
  function parseParms(str) {
    const list = str.split("#")[1];
    var pieces = list.split("&"), data = {}, i, parts;
    for (i = 0; i < pieces.length; i++) {
      parts = pieces[i].split("=");
      if (parts.length < 2) {
        parts.push("");
      }
      data[decodeURIComponent(parts[0])] = decodeURIComponent(parts[1]);
    }
    return data;
  }

  return (
    <Container className="p-3">
      {document.URL.includes("id_token=")
        ? <div><Button onClick={() => render_tokens()} variant="primary">Show Token Detail</Button><p></p><p></p><p></p>
          <p style={{ color: 'green' }}> User is now logged in. The id and access tokens returned by Cognito are in the URL.</p>
          <p> Logged in user as access to the following projects</p><textarea id="list_of_projects" rows="2" cols="80"></textarea><p></p><p></p><p></p>
          <p> Raw ID Token </p><textarea id="raw_id_token" rows="4" cols="80"></textarea><p></p><p></p><p></p>
          <p> Decoded ID Token </p><textarea id="decoded_id_token" rows="15" cols="80"></textarea><p></p><p></p><p></p></div>
        : <Button onClick={() => render_login()} variant="primary">Login</Button>
      }
    </Container>
  );
}

export default App;
