#
#  Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
#  This file is licensed under the Apache License, Version 2.0 (the "License").
#  You may not use this file except in compliance with the License. A copy of
#  the License is located at
# 
#  http://aws.amazon.com/apache2.0/
# 
#  This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
#  CONDITIONS OF ANY KIND, either express or implied. See the License for the
#  specific language governing permissions and limitations under the License.
#
import sys
import time
import json
import os
import cloud_formation_utils
import cognito_utils
import ddb_utils
import lambda_utils
from datetime import datetime


#Set up parameters for the stack
with open("stackInputs.json", encoding='utf-8-sig') as json_file_text:
    stack_params = json.load(json_file_text)

#Call the function that creates the stack
list_of_outputs = cloud_formation_utils.createPreTokenStack(stack_params)

print("Stack creation outputs")
print("-------")
for k, v in list_of_outputs.items():
    print(k, " : ", v)
print("-------")

# Print the list_of_outputs in stackOutputs.json file so that it can be read later. 
f = open("stackOutputs.json", "w")
f.write(json.dumps(list_of_outputs, sort_keys=True, indent=4))
f.close()

#Add the pre-token-generation lambda trigger to the cognito userpool
try:
    configurePreTokenGenerationLambda_input = {
        "CongnitoUserPoolId": list_of_outputs["CongnitoUserPoolId"],
        "lambdaFunctionArn": lambda_utils.getLambdaArn(list_of_outputs["LambdaFunction"])
    }
    cognito_utils.configurePreTokenGenerationTrigger(configurePreTokenGenerationLambda_input)
    print("The pre-token-generation lambda trigger is configured.")
except Exception as e:
    print(e)
    raise e


#Configure lambda Resource based policy
try:
    configureLambdaResourceBasedPolicy_input = {
        "CongnitoUserPoolId": list_of_outputs["CongnitoUserPoolId"],
        "LambdaFunction": list_of_outputs["LambdaFunction"],
        "CongnitoUserPoolARN": list_of_outputs["CongnitoUserPoolARN"]
    }

    lambda_utils.configureLambdaResourceBasedPolicy(configureLambdaResourceBasedPolicy_input)
    print("The lambda Resource based policy is configured.")
except Exception as e:
    print(e)
    raise e

# Print the URL required for login in the costants.js file that will be used for login button click.
f = open("pre-token-web-app/src/constants.js", "w")
f.write("const redirectUrls = {cognitoLoginURL: \"")
f.write(list_of_outputs["CognitoUserPoolDomain"] + "/login?response_type=token&client_id=" + list_of_outputs["CognitoUserPoolClientId"] + "&redirect_uri=" + cloud_formation_utils.get_callback_url(list_of_outputs["CongnitoUserPoolId"],list_of_outputs["CognitoUserPoolClientId"]))
f.write("\"};export { redirectUrls };")
f.close()


